==> mgb-0.5.4-de.zip: mgb-0.5.4-de/functions.php <==
<?php
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

// Zensurfunktion
if (!function_exists("badwords"))
	{
	function badwords($text)
		{
		global $badwords;
		foreach($badwords as $b)
			{// ersetzen
			$r = $b[0].str_repeat("*", strlen($b)-2).$b[strlen($b)-1];
			if(function_exists("str_ireplace"))
				{
				$text = str_ireplace($b, $r, $text);
				}
			else
				{
				$text = str_replace($b, $r, $text);
				}
                         }
                         return $text;
                }
         }

// berprft ob eine eMail existieren kann
if (!function_exists("check_mail"))
	{
	// @param string $email
	function check_mail($email)
   		{
		if (eregi("^[a-z0-9]+([-_\.]?[a-z0-9])+@[a-z0-9]+([-_\.]?[a-z0-9])+\.[a-z]{2,4}", $email))
			{
			return TRUE;
			}
		else
			{
			return FALSE;
			}
                }
        }

// berprft ob eine Internet Adresse existieren kann
//if (!function_exists("check_http"))
//	{
//	// @param string $email
//	function check_http($http)
//   		{
//		if (eregi(?:^|")(http|ftp|mailto)*:*(//)*(\w+(?:[\.:@]\w+)*?)(?:/|@)?([^"\?]*?)(?:\?([^\?"]*?))?(?:$|", $http))
//			{
//			return TRUE;
//			}
//		else
//			{
//			return FALSE;
//			}
//                }
//        }

// berprft ob eine ICQ Nummer auch wirklich eine ICQ Nummer
// ist, und keine anderen Zeichen als Zahlen enthlt
if (!function_exists("check_number"))
	{
         // @param string $nummer
         function check_number($nummer)
                 {
                 if (preg_match("=^[0-9]+$=i",$nummer))
                         {
                         return TRUE;
                         }
                else
                         {
                         return FALSE;
                         }
                 }
         }

// BBCode umsetzen
if (!function_exists("bbcode_format"))
	{
	function bbcode_format($bbcode)
		{
		//$bbcode = htmlentities($bbcode);

                 $simple_search = array(
                 			'/\[b\](.*?)\[\/b\]/is',
                                		'/\[i\](.*?)\[\/i\]/is',
                                         '/\[url\](.*?)\[\/url\]/is',
                                         '/\[url\=(.*?)\](.*?)\[\/url\]/is',
                                         '/\[size\=(.*?)\](.*?)\[\/size\]/is',
                                         '/\[color\=(.*?)\](.*?)\[\/color\]/is'
                                	 	);

        		$simple_replace = array(
                                		'<b>$1</b>',
                                		'<i>$1</i>',
                                         '<a href="$1" target="_blank">$1</a>',
                                         '<a href="$1" target="_blank">$2</a>',
                                         '<span style="font-size:$1px;">$2</span>',
                                         '<span style="color:#$1;">$2</span>'
                                		);

        		$bbcode = preg_replace ($simple_search, $simple_replace, $bbcode);

        		return $bbcode;
		}
         }

// BBCode umsetzen
if (!function_exists("bbcode_delete"))
	{
	function bbcode_delete($bbcode)
		{
		//$bbcode = htmlentities($bbcode);

                 $simple_search = array(
                 			'/\[b\](.*?)\[\/b\]/is',
                                		'/\[i\](.*?)\[\/i\]/is',
                                         '/\[url\](.*?)\[\/url\]/is',
                                         '/\[url\=(.*?)\](.*?)\[\/url\]/is',
                                         '/\[size\=(.*?)\](.*?)\[\/size\]/is',
                                         '/\[color\=(.*?)\](.*?)\[\/color\]/is'
                                	 	);

        		$simple_replace = array(
                                		'$1',
                                		'$1',
                                         '$1',
                                         '$1',
                                         '$2',
                                         '$2'
                                		);

        		$bbcode = preg_replace ($simple_search, $simple_replace, $bbcode);

        		return $bbcode;
		}
         }
?>

==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/functions.php <==
<?php
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

// Zensurfunktion
if (!function_exists("badwords"))
	{
	function badwords($text)
		{
		global $badwords;
		foreach($badwords as $b)
			{// ersetzen
			$r = $b[0].str_repeat("*", strlen($b)-2).$b[strlen($b)-1];
			if(function_exists("str_ireplace"))
				{
				$text = str_ireplace($b, $r, $text);
				}
			else
				{
				$text = str_replace($b, $r, $text);
				}
                         }
                         return $text;
                }
         }

// berprft ob eine eMail existieren kann
if (!function_exists("check_mail"))
	{
	// @param string $email
	function check_mail($email)
   		{
		if (eregi("^[a-z0-9]+([-_\.]?[a-z0-9])+@[a-z0-9]+([-_\.]?[a-z0-9])+\.[a-z]{2,4}", $email))
			{
			return TRUE;
			}
		else
			{
			return FALSE;
			}
                }
        }

// berprft ob eine ICQ Nummer auch wirklich eine ICQ Nummer
// ist, und keine anderen Zeichen als Zahlen enthlt
if (!function_exists("check_number"))
	{
         // @param string $nummer
         function check_number($nummer)
                 {
                 if (preg_match("=^[0-9]+$=i",$nummer))
                         {
                         return TRUE;
                         }
                else
                         {
                         return FALSE;
                         }
                 }
         }

// BBCode umsetzen
if (!function_exists("bbcode_format"))
	{
	function bbcode_format($bbcode)
		{
		//$bbcode = htmlentities($bbcode);

                 $simple_search = array(
                 			'/\[b\](.*?)\[\/b\]/is',
                                		'/\[i\](.*?)\[\/i\]/is',
                                         '/\[url\](.*?)\[\/url\]/is',
                                         '/\[url\=(.*?)\](.*?)\[\/url\]/is',
                                         '/\[size\=(.*?)\](.*?)\[\/size\]/is',
                                         '/\[color\=(.*?)\](.*?)\[\/color\]/is'
                                	 	);

        		$simple_replace = array(
                                		'<b>$1</b>',
                                		'<i>$1</i>',
                                         '<a href="$1" target="_blank">$1</a>',
                                         '<a href="$1" target="_blank">$2</a>',
                                         '<span style="font-size:$1px;">$2</span>',
                                         '<span style="color:#$1;">$2</span>'
                                		);

        		$bbcode = preg_replace ($simple_search, $simple_replace, $bbcode);

        		return $bbcode;
		}
         }

// BBCode umsetzen
if (!function_exists("bbcode_delete"))
	{
	function bbcode_delete($bbcode)
		{
		//$bbcode = htmlentities($bbcode);

                 $simple_search = array(
                 			'/\[b\](.*?)\[\/b\]/is',
                                		'/\[i\](.*?)\[\/i\]/is',
                                         '/\[url\](.*?)\[\/url\]/is',
                                         '/\[url\=(.*?)\](.*?)\[\/url\]/is',
                                         '/\[size\=(.*?)\](.*?)\[\/size\]/is',
                                         '/\[color\=(.*?)\](.*?)\[\/color\]/is'
                                	 	);

        		$simple_replace = array(
                                		'$1',
                                		'$1',
                                         '$1',
                                         '$1',
                                         '$2',
                                         '$2'
                                		);

        		$bbcode = preg_replace ($simple_search, $simple_replace, $bbcode);

        		return $bbcode;
		}
         }
?>
